@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -43,7 +43,7 @@
 
 ThemeEditorMainWindow::ThemeEditorMainWindow()
     : KXmlGuiWindow(),
-      mThemeEditor(0)
+      mThemeEditor(nullptr)
 {
     setupActions();
     setupGUI();
@@ -76,7 +76,7 @@ void ThemeEditorMainWindow::readConfig()
 
 void ThemeEditorMainWindow::updateActions()
 {
-    const bool projectDirectoryIsEmpty = (mThemeEditor != 0);
+    const bool projectDirectoryIsEmpty = (mThemeEditor != nullptr);
     mAddExtraPage->setEnabled(projectDirectoryIsEmpty);
     mCloseAction->setEnabled(projectDirectoryIsEmpty);
     mUploadTheme->setEnabled(projectDirectoryIsEmpty);
@@ -240,8 +240,8 @@ void ThemeEditorMainWindow::slotAddExtraPage()
 void ThemeEditorMainWindow::closeThemeEditor()
 {
     delete mThemeEditor;
-    mThemeEditor = 0;
-    setCentralWidget(0);
+    mThemeEditor = nullptr;
+    setCentralWidget(nullptr);
     updateActions();
 }
 
@@ -261,7 +261,7 @@ bool ThemeEditorMainWindow::saveCurrentProject(ActionSaveTheme act)
     }
     case SaveAndCreateNewTheme: {
         delete mThemeEditor;
-        mThemeEditor = 0;
+        mThemeEditor = nullptr;
         QPointer<GrantleeThemeEditor::NewThemeDialog> dialog = new GrantleeThemeEditor::NewThemeDialog(this);
         QString newTheme;
         QString projectDirectory;
@@ -276,7 +276,7 @@ bool ThemeEditorMainWindow::saveCurrentProject(ActionSaveTheme act)
             connect(mThemeEditor, &ThemeEditorPage::canInsertFile, this, &ThemeEditorMainWindow::slotCanInsertFile);
             setCentralWidget(mThemeEditor);
         } else {
-            setCentralWidget(0);
+            setCentralWidget(nullptr);
         }
         delete dialog;
         updateActions();
