@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -33,8 +33,8 @@ using namespace GrantleeThemeEditor;
 EditorPage::EditorPage(PageType type, QWidget *parent)
     : QWidget(parent),
       mType(type),
-      mPreview(0),
-      mEditor(0)
+      mPreview(nullptr),
+      mEditor(nullptr)
 {
 }
 
